<template>
    <div >
        <!-- Add invoice scheme-->
        <InvoiceSchemeAdd ref="invoiceSchemeAdd"></InvoiceSchemeAdd>
        <!-- Edit invoice scheme-->
        <InvoiceSchemeEdit ref="invoiceSchemeEdit"></InvoiceSchemeEdit>
        <v-card>
            <v-card-title>
                <div>
                    <div class="headline">
                        {{ trans('messages.all_invoice_schemes') }}
                    </div>
                </div>
                <v-spacer></v-spacer>
                <v-btn
                    v-if="$can('invoice_scheme.create')"
                    class="primary lighten-1"
                    dark
                    @click="$refs.invoiceSchemeAdd.create()"
                >
                    {{ trans('messages.new_scheme') }}
                    <v-icon right dark>add</v-icon>
                </v-btn>
            </v-card-title>
            <v-divider></v-divider>
            <!-- dataTable -->
            <v-data-table
                :headers="headers"
                :options.sync="pagination"
                :server-items-length="total_items"
                :loading="loading"
                :items="items"
                class="elevation-3"
            >
                <template v-slot:item="{ item }">
                    <tr>
                        <td class="text-center">
                            <v-menu>
                                <template v-slot:activator="{ on }">
                                    <v-btn icon v-on="on">
                                        <v-icon>more_vert</v-icon>
                                    </v-btn>
                                </template>
                                <v-list>
                                    <v-list-item @click="edit(item)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> edit </v-icon>
                                            {{ trans('messages.edit') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                    <v-list-item @click="deleteInvoiceScheme(item)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> delete_forever </v-icon>
                                            {{ trans('messages.delete') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                </v-list>
                            </v-menu>
                        </td>
                        <td class="text-center">
                            {{ item.name }}
                            <v-chip
                                color="green"
                                text-color="white"
                                small
                                v-if="item.is_default == 1"
                                >{{ trans('messages.default') }}</v-chip
                            >
                        </td>
                        <td class="text-center">
                            {{ item.scheme_type == 'year' ? year_prefix : item.prefix }}
                        </td>
                        <td class="text-center">{{ item.start_number }}</td>
                        <td class="text-center">{{ item.invoice_count }}</td>
                        <td class="text-center">{{ item.total_digits }}</td>
                    </tr>
                </template>
            </v-data-table>
            <!-- /dataTable -->
        </v-card>
    </div>
</template>
<script>
import InvoiceSchemeAdd from './Add';
import InvoiceSchemeEdit from './Edit';
export default {
    components: {
        InvoiceSchemeAdd,
        InvoiceSchemeEdit,
    },
    data() {
        const self = this;
        return {
            total_items: 0,
            loading: true,
            pagination: {},
            headers: [
                {
                    text: self.trans('messages.action'),
                    value: false,
                    align: 'center',
                    sortable: false,
                },
                { text: self.trans('messages.name'), value: 'name', align: 'center', sortable: true },
                {
                    text: self.trans('messages.prefix'),
                    value: 'prefix',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.start_from'),
                    value: 'start_number',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.invoice_count'),
                    value: 'invoice_count',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.no_of_digits'),
                    value: 'total_digits',
                    align: 'center',
                    sortable: true,
                },
            ],
            items: [],
            year_prefix: '#' + moment().format('YYYY'),
        };
    },
    created() {
        const self = this;
        self.$eventBus.$on('updateInvoiceSchemeTable', data => {
            self.getInvoiceSchemeFromApi();
        });
    },
    beforeDestroy() {
        const self = this;
        self.$eventBus.$off('updateInvoiceSchemeTable');
    },
    watch: {
        pagination: {
            handler() {
                this.getInvoiceSchemeFromApi();
            },
        },
    },
    methods: {
        getInvoiceSchemeFromApi() {
            const self = this;
            self.loading = true;
            const { sortBy, sortDesc, page, itemsPerPage } = self.pagination;

            var params = {
                sort_by: sortBy,
                descending: sortDesc,
                page: page,
                rowsPerPage: itemsPerPage,
            };

            axios
                .get('/admin/invoice-scheme', {
                    params: params,
                })
                .then(function(response) {
                    self.total_items = response.data.total;
                    self.items = response.data.data;
                    self.loading = false;
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        deleteInvoiceScheme(invoice_scheme) {
            const self = this;
            self.$store.commit('showDialog', {
                type: 'confirm',
                icon: 'warning',
                title: self.trans('messages.are_you_sure'),
                message: self.trans('messages.you_cant_restore_it'),
                okCb: () => {
                    axios
                        .delete('admin/invoice-scheme/' + invoice_scheme.id)
                        .then(function(response) {
                            self.$store.commit('showSnackbar', {
                                message: response.data.msg,
                                color: response.data.success,
                            });

                            if (response.data.success === true) {
                                self.getInvoiceSchemeFromApi();
                            }
                        })
                        .catch(function(error) {
                            console.log(error);
                        });
                },
                cancelCb: () => {
                    console.log('CANCEL');
                },
            });
        },
        edit(invoice_scheme) {
            var data = { id: invoice_scheme.id };
            this.$refs.invoiceSchemeEdit.edit(data);
        },
    },
};
</script>
